@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::ReadmeAnyFromPod;
 {
-  $Dist::Zilla::Plugin::ReadmeAnyFromPod::VERSION = '0.132973'; # TRIAL
+  $Dist::Zilla::Plugin::ReadmeAnyFromPod::VERSION = '0.133000'; # TRIAL
 }
 # ABSTRACT: Automatically convert POD to a README in any format for Dist::Zilla
 
@@ -18,10 +18,10 @@ use PPI::Document;
 use PPI::Token::Pod;
 use Scalar::Util 'blessed';
 
-with 'Dist::Zilla::Role::AfterBuild' => { -version => 5 };
-with 'Dist::Zilla::Role::FileGatherer' => { -version => 5 };
-with 'Dist::Zilla::Role::FileMunger' => { -version => 5 };
-with 'Dist::Zilla::Role::FilePruner' => { -version => 5 };
+with 'Dist::Zilla::Role::AfterBuild';
+with 'Dist::Zilla::Role::FileGatherer';
+with 'Dist::Zilla::Role::FileMunger';
+with 'Dist::Zilla::Role::FilePruner';
 
 # TODO: Should these be separate modules?
 our $_types = {
@@ -175,7 +175,7 @@ sub munge_file {
             if ($newcontent ne $plugin->_last_source_content)
             {
                 $plugin->log('someone tried to munge ' . $source_file->name . ' after we read from it. Making modifications again...');
-                $plugin->munge_file($self);
+                $plugin->munge_file($file);
             }
         });
 
@@ -202,9 +202,12 @@ sub after_build {
         if (-e $file) {
             $self->log("overriding $filename in root");
         }
-        my $encoded_content = encode($self->_get_source_encoding(),
-                                     $content);
-        Path::Tiny::path($file)->spew_raw($encoded_content);
+        my $encoding = $self->_get_source_encoding();
+        Path::Tiny::path($file)->spew_raw(
+            $encoding eq 'raw'
+                ? $content
+                : encode($encoding, $content)
+        );
     }
 
     return;
@@ -253,7 +256,10 @@ sub _get_source_pod {
 
 sub _get_source_encoding {
     my ($self) = shift;
-    $self->_source_file->encoding;
+    return
+        $self->_source_file->can('encoding')
+            ? $self->_source_file->encoding
+            : 'raw';        # Dist::Zilla pre-5.0
 }
 
 
@@ -300,7 +306,7 @@ Dist::Zilla::Plugin::ReadmeAnyFromPod - Automatically convert POD to a README in
 
 =head1 VERSION
 
-version 0.132973
+version 0.133000
 
 =head1 SYNOPSIS
 
